@@ -29,7 +29,7 @@
 #include <tdemessagebox.h>
 #include <kuser.h>
 
-#include <kscoredialog.h>
+#include <highscore/kscoredialog.h>
 
 
 #include "kbattleship.moc"
@@ -92,16 +92,16 @@ void KBattleshipWindow::initStatusBar()
 
 void KBattleshipWindow::initActions()
 {
-	KStdAction::configureNotifications(TQT_TQOBJECT(this), TQT_SLOT(slotConfigureNotifications()), actionCollection());
-	m_gameServerConnect = new TDEAction(i18n("&Connect to Server..."), "connect_no", Key_F2, TQT_TQOBJECT(this), TQT_SLOT(slotServerConnect()), actionCollection(), "game_serverconnect");
-	m_gameNewServer = new TDEAction(i18n("&Start Server..."), "network", Key_F3, TQT_TQOBJECT(this), TQT_SLOT(slotNewServer()), actionCollection(), "game_newserver");
-	m_gameSingle = new TDEAction(i18n("S&ingle Player..."), "gear", Key_F4, TQT_TQOBJECT(this), TQT_SLOT(slotSinglePlayer()), actionCollection(), "game_singleplayer");
-	m_gameQuit = KStdGameAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
-	KStdGameAction::highscores(TQT_TQOBJECT(this), TQT_SLOT(slotHighscore()), actionCollection());
-	m_gameEnemyInfo = new TDEAction(i18n("&Enemy Info"), "view_text", Key_F11, TQT_TQOBJECT(this), TQT_SLOT(slotEnemyClientInfo()), actionCollection(), "game_enemyinfo");
+	KStdAction::configureNotifications(this, TQ_SLOT(slotConfigureNotifications()), actionCollection());
+	m_gameServerConnect = new TDEAction(i18n("&Connect to Server..."), "connect_no", Key_F2, this, TQ_SLOT(slotServerConnect()), actionCollection(), "game_serverconnect");
+	m_gameNewServer = new TDEAction(i18n("&Start Server..."), "network", Key_F3, this, TQ_SLOT(slotNewServer()), actionCollection(), "game_newserver");
+	m_gameSingle = new TDEAction(i18n("S&ingle Player..."), "gear", Key_F4, this, TQ_SLOT(slotSinglePlayer()), actionCollection(), "game_singleplayer");
+	m_gameQuit = KStdGameAction::quit(this, TQ_SLOT(close()), actionCollection());
+	KStdGameAction::highscores(this, TQ_SLOT(slotHighscore()), actionCollection());
+	m_gameEnemyInfo = new TDEAction(i18n("&Enemy Info"), "view_text", Key_F11, this, TQ_SLOT(slotEnemyClientInfo()), actionCollection(), "game_enemyinfo");
 
 	m_configSound = new TDEToggleAction(i18n("&Play Sounds"), 0, actionCollection(), "options_configure_sound");
-	m_configGrid = new TDEToggleAction(i18n("&Show Grid"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotShowGrid()), actionCollection(), "options_show_grid");
+	m_configGrid = new TDEToggleAction(i18n("&Show Grid"), 0, this, TQ_SLOT(slotShowGrid()), actionCollection(), "options_show_grid");
 	m_configGrid->setCheckedState(i18n("Hide Grid"));
 
 	m_gameEnemyInfo->setEnabled(false);
@@ -111,9 +111,9 @@ void KBattleshipWindow::initActions()
 
 void KBattleshipWindow::initChat()
 {
-	connect(m_chat, TQT_SIGNAL(sigSendMessage(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotSendChatMessage(const TQString &)));
-	connect(m_chat, TQT_SIGNAL(sigChangeEnemyNickname(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeEnemyPlayer(const TQString &)));
-	connect(m_chat, TQT_SIGNAL(sigChangeOwnNickname(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotChangedNickCommand(const TQString &)));
+	connect(m_chat, TQ_SIGNAL(sigSendMessage(const TQString &)), this, TQ_SLOT(slotSendChatMessage(const TQString &)));
+	connect(m_chat, TQ_SIGNAL(sigChangeEnemyNickname(const TQString &)), this, TQ_SLOT(slotChangeEnemyPlayer(const TQString &)));
+	connect(m_chat, TQ_SIGNAL(sigChangeOwnNickname(const TQString &)), this, TQ_SLOT(slotChangedNickCommand(const TQString &)));
 }
 
 void KBattleshipWindow::changeShipPlacementDirection(){
@@ -122,8 +122,8 @@ void KBattleshipWindow::changeShipPlacementDirection(){
 
 void KBattleshipWindow::initShipPlacing()
 {
-	connect(m_ownshiplist, TQT_SIGNAL(sigOwnFieldDataChanged(int, int, int)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeOwnFieldData(int, int, int)));
-	connect(m_ownshiplist, TQT_SIGNAL(sigLastShipAdded()), TQT_TQOBJECT(this), TQT_SLOT(slotShipsReady()));
+	connect(m_ownshiplist, TQ_SIGNAL(sigOwnFieldDataChanged(int, int, int)), this, TQ_SLOT(slotChangeOwnFieldData(int, int, int)));
+	connect(m_ownshiplist, TQ_SIGNAL(sigLastShipAdded()), this, TQ_SLOT(slotShipsReady()));
 }
 
 void KBattleshipWindow::initView()
@@ -148,10 +148,10 @@ void KBattleshipWindow::initView()
 	m_view->startDrawing();
 	setFocusProxy(m_view);
 
-	connect(m_view, TQT_SIGNAL(sigEnemyFieldClicked(int, int)), TQT_TQOBJECT(this), TQT_SLOT(slotEnemyFieldClick(int, int)));
-	connect(m_view, TQT_SIGNAL(sigOwnFieldClicked(int, int)), TQT_TQOBJECT(this), TQT_SLOT(slotPlaceShip(int, int)));
-	connect(m_view, TQT_SIGNAL(sigMouseOverField(int, int)), TQT_TQOBJECT(this), TQT_SLOT(slotPlaceShipPreview(int, int)));
-	connect(m_view, TQT_SIGNAL(changeShipPlacementDirection()), TQT_TQOBJECT(this), TQT_SLOT(changeShipPlacementDirection()));
+	connect(m_view, TQ_SIGNAL(sigEnemyFieldClicked(int, int)), this, TQ_SLOT(slotEnemyFieldClick(int, int)));
+	connect(m_view, TQ_SIGNAL(sigOwnFieldClicked(int, int)), this, TQ_SLOT(slotPlaceShip(int, int)));
+	connect(m_view, TQ_SIGNAL(sigMouseOverField(int, int)), this, TQ_SLOT(slotPlaceShipPreview(int, int)));
+	connect(m_view, TQ_SIGNAL(changeShipPlacementDirection()), this, TQ_SLOT(changeShipPlacementDirection()));
 }
 
 void KBattleshipWindow::slotDeleteAI()
@@ -317,11 +317,11 @@ void KBattleshipWindow::slotEnemyFieldClick(int fieldx, int fieldy)
 				switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?"),TQString(),i18n("Restart"),i18n("Do Not Restart")))
 				{
 					case KMessageBox::Yes:
-						TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(slotRestartAI()));
+						TQTimer::singleShot(0, this, TQ_SLOT(slotRestartAI()));
 						break;
 
 					case KMessageBox::No:
-						TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(slotDeleteAI()));
+						TQTimer::singleShot(0, this, TQ_SLOT(slotDeleteAI()));
 						break;
 				}
 				return;
@@ -697,8 +697,8 @@ void KBattleshipWindow::slotServerConnect()
 		slotStatusMsg(i18n("Loading Connect-Server dialog..."));
 
 		m_client = new KClientDialog(this);
-		connect(m_client, TQT_SIGNAL(sigConnectServer()), TQT_TQOBJECT(this), TQT_SLOT(slotConnectToBattleshipServer()));
-		connect(m_client, TQT_SIGNAL(sigCancelConnect()), TQT_TQOBJECT(this), TQT_SLOT(slotDeleteConnectDialog()));
+		connect(m_client, TQ_SIGNAL(sigConnectServer()), this, TQ_SLOT(slotConnectToBattleshipServer()));
+		connect(m_client, TQ_SIGNAL(sigCancelConnect()), this, TQ_SLOT(slotDeleteConnectDialog()));
 		m_client->show();
 
 		slotStatusMsg(i18n("Ready"));
@@ -806,8 +806,8 @@ void KBattleshipWindow::slotNewServer()
 		slotStatusMsg(i18n("Loading Start-Server dialog..."));
 
 		m_server = new TDEServerDialog(this);
-		connect(m_server, TQT_SIGNAL(okClicked()), TQT_TQOBJECT(this), TQT_SLOT(slotStartBattleshipServer()));
-		connect(m_server, TQT_SIGNAL(cancelClicked()), TQT_TQOBJECT(this), TQT_SLOT(slotDeleteServerDialog()));
+		connect(m_server, TQ_SIGNAL(okClicked()), this, TQ_SLOT(slotStartBattleshipServer()));
+		connect(m_server, TQ_SIGNAL(cancelClicked()), this, TQ_SLOT(slotDeleteServerDialog()));
 		m_server->show();
 
 		slotStatusMsg(i18n("Ready"));
@@ -828,7 +828,7 @@ void KBattleshipWindow::slotSendVersion()
 	msg->versionMessage();
 	slotSendMessage(msg);
 
-	TQTimer::singleShot(150, TQT_TQOBJECT(this), TQT_SLOT(slotSendGreet()));
+	TQTimer::singleShot(150, this, TQ_SLOT(slotSendGreet()));
 }
 
 void KBattleshipWindow::slotSendGreet()
@@ -862,49 +862,49 @@ void KBattleshipWindow::slotStartBattleshipServer()
 	if(m_connection == 0)
 	{
 		m_connection = new KonnectionHandling(this, m_kbserver);
-		connect(m_connection, TQT_SIGNAL(sigStatusBar(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotStatusMsg(const TQString &)));
-		connect(m_connection, TQT_SIGNAL(sigEnemyNickname(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeEnemyPlayer(const TQString &)));
-		connect(m_connection, TQT_SIGNAL(sigSendNickname()), TQT_TQOBJECT(this), TQT_SLOT(slotSendGreet()));
-		connect(m_connection, TQT_SIGNAL(sigPlaceShips(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetPlaceable(bool)));
-		connect(m_connection, TQT_SIGNAL(sigShootable(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetShootable(bool)));
-		connect(m_connection, TQT_SIGNAL(sigSendFieldState(int, int)), TQT_TQOBJECT(this), TQT_SLOT(slotSendEnemyFieldState(int, int)));
-		connect(m_connection, TQT_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), TQT_TQOBJECT(this), TQT_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
-		connect(m_connection, TQT_SIGNAL(sigClientLost()), TQT_TQOBJECT(this), TQT_SLOT(slotClientLost()));
-		connect(m_connection, TQT_SIGNAL(sigAbortNetworkGame()), TQT_TQOBJECT(this), TQT_SLOT(slotAbortNetworkGame()));
-		connect(m_connection, TQT_SIGNAL(sigReplay()), TQT_TQOBJECT(this), TQT_SLOT(slotReplayRequest()));
-		connect(m_connection, TQT_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQT_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
-		connect(m_connection, TQT_SIGNAL(sigClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotReceivedClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)));
-		connect(m_connection, TQT_SIGNAL(sigLost(KMessage *)), TQT_TQOBJECT(this), TQT_SLOT(slotLost(KMessage *)));
+		connect(m_connection, TQ_SIGNAL(sigStatusBar(const TQString &)), this, TQ_SLOT(slotStatusMsg(const TQString &)));
+		connect(m_connection, TQ_SIGNAL(sigEnemyNickname(const TQString &)), this, TQ_SLOT(slotChangeEnemyPlayer(const TQString &)));
+		connect(m_connection, TQ_SIGNAL(sigSendNickname()), this, TQ_SLOT(slotSendGreet()));
+		connect(m_connection, TQ_SIGNAL(sigPlaceShips(bool)), this, TQ_SLOT(slotSetPlaceable(bool)));
+		connect(m_connection, TQ_SIGNAL(sigShootable(bool)), this, TQ_SLOT(slotSetShootable(bool)));
+		connect(m_connection, TQ_SIGNAL(sigSendFieldState(int, int)), this, TQ_SLOT(slotSendEnemyFieldState(int, int)));
+		connect(m_connection, TQ_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), this, TQ_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
+		connect(m_connection, TQ_SIGNAL(sigClientLost()), this, TQ_SLOT(slotClientLost()));
+		connect(m_connection, TQ_SIGNAL(sigAbortNetworkGame()), this, TQ_SLOT(slotAbortNetworkGame()));
+		connect(m_connection, TQ_SIGNAL(sigReplay()), this, TQ_SLOT(slotReplayRequest()));
+		connect(m_connection, TQ_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQ_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
+		connect(m_connection, TQ_SIGNAL(sigClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)), this, TQ_SLOT(slotReceivedClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)));
+		connect(m_connection, TQ_SIGNAL(sigLost(KMessage *)), this, TQ_SLOT(slotLost(KMessage *)));
 	}
 	else
 	{
 		if(m_connection->type() == KonnectionHandling::CLIENT)
 		{
-			disconnect(m_kbclient, TQT_SIGNAL(sigConnected()), TQT_TQOBJECT(this), TQT_SLOT(slotSendVersion()));
-			disconnect(m_connection, TQT_SIGNAL(sigAbortNetworkGame()), TQT_TQOBJECT(this), TQT_SLOT(slotAbortNetworkGame()));
-			disconnect(m_connection, TQT_SIGNAL(sigStatusBar(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotStatusMsg(const TQString &)));
-			disconnect(m_connection, TQT_SIGNAL(sigEnemyNickname(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeEnemyPlayer(const TQString &)));
-			disconnect(m_connection, TQT_SIGNAL(sigSendFieldState(int, int)), TQT_TQOBJECT(this), TQT_SLOT(slotSendEnemyFieldState(int, int)));
-			disconnect(m_connection, TQT_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), TQT_TQOBJECT(this), TQT_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
-			disconnect(m_connection, TQT_SIGNAL(sigShootable(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetShootable(bool)));
-			disconnect(m_connection, TQT_SIGNAL(sigPlaceShips(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetPlaceable(bool)));
-			disconnect(m_connection, TQT_SIGNAL(sigServerLost()), TQT_TQOBJECT(this), TQT_SLOT(slotServerLost()));
-			disconnect(m_connection, TQT_SIGNAL(sigReplay()), TQT_TQOBJECT(this), TQT_SLOT(slotReplay()));
-			disconnect(m_connection, TQT_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQT_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
-			disconnect(m_connection, TQT_SIGNAL(sigLost(KMessage *)), TQT_TQOBJECT(this), TQT_SLOT(slotLost(KMessage *)));
+			disconnect(m_kbclient, TQ_SIGNAL(sigConnected()), this, TQ_SLOT(slotSendVersion()));
+			disconnect(m_connection, TQ_SIGNAL(sigAbortNetworkGame()), this, TQ_SLOT(slotAbortNetworkGame()));
+			disconnect(m_connection, TQ_SIGNAL(sigStatusBar(const TQString &)), this, TQ_SLOT(slotStatusMsg(const TQString &)));
+			disconnect(m_connection, TQ_SIGNAL(sigEnemyNickname(const TQString &)), this, TQ_SLOT(slotChangeEnemyPlayer(const TQString &)));
+			disconnect(m_connection, TQ_SIGNAL(sigSendFieldState(int, int)), this, TQ_SLOT(slotSendEnemyFieldState(int, int)));
+			disconnect(m_connection, TQ_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), this, TQ_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
+			disconnect(m_connection, TQ_SIGNAL(sigShootable(bool)), this, TQ_SLOT(slotSetShootable(bool)));
+			disconnect(m_connection, TQ_SIGNAL(sigPlaceShips(bool)), this, TQ_SLOT(slotSetPlaceable(bool)));
+			disconnect(m_connection, TQ_SIGNAL(sigServerLost()), this, TQ_SLOT(slotServerLost()));
+			disconnect(m_connection, TQ_SIGNAL(sigReplay()), this, TQ_SLOT(slotReplay()));
+			disconnect(m_connection, TQ_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQ_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
+			disconnect(m_connection, TQ_SIGNAL(sigLost(KMessage *)), this, TQ_SLOT(slotLost(KMessage *)));
 			m_connection->updateInternal(m_kbserver);
-			connect(m_connection, TQT_SIGNAL(sigStatusBar(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotStatusMsg(const TQString &)));
-			connect(m_connection, TQT_SIGNAL(sigEnemyNickname(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeEnemyPlayer(const TQString &)));
-			connect(m_connection, TQT_SIGNAL(sigSendNickname()), TQT_TQOBJECT(this), TQT_SLOT(slotSendGreet()));
-			connect(m_connection, TQT_SIGNAL(sigPlaceShips(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetPlaceable(bool)));
-			connect(m_connection, TQT_SIGNAL(sigShootable(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetShootable(bool)));
-			connect(m_connection, TQT_SIGNAL(sigSendFieldState(int, int)), TQT_TQOBJECT(this), TQT_SLOT(slotSendEnemyFieldState(int, int)));
-			connect(m_connection, TQT_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), TQT_TQOBJECT(this), TQT_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
-			connect(m_connection, TQT_SIGNAL(sigClientLost()), TQT_TQOBJECT(this), TQT_SLOT(slotClientLost()));
-			connect(m_connection, TQT_SIGNAL(sigAbortNetworkGame()), TQT_TQOBJECT(this), TQT_SLOT(slotAbortNetworkGame()));
-			connect(m_connection, TQT_SIGNAL(sigReplay()), TQT_TQOBJECT(this), TQT_SLOT(slotReplayRequest()));
-			connect(m_connection, TQT_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQT_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
-			connect(m_connection, TQT_SIGNAL(sigLost(KMessage *)), TQT_TQOBJECT(this), TQT_SLOT(slotLost(KMessage *)));
+			connect(m_connection, TQ_SIGNAL(sigStatusBar(const TQString &)), this, TQ_SLOT(slotStatusMsg(const TQString &)));
+			connect(m_connection, TQ_SIGNAL(sigEnemyNickname(const TQString &)), this, TQ_SLOT(slotChangeEnemyPlayer(const TQString &)));
+			connect(m_connection, TQ_SIGNAL(sigSendNickname()), this, TQ_SLOT(slotSendGreet()));
+			connect(m_connection, TQ_SIGNAL(sigPlaceShips(bool)), this, TQ_SLOT(slotSetPlaceable(bool)));
+			connect(m_connection, TQ_SIGNAL(sigShootable(bool)), this, TQ_SLOT(slotSetShootable(bool)));
+			connect(m_connection, TQ_SIGNAL(sigSendFieldState(int, int)), this, TQ_SLOT(slotSendEnemyFieldState(int, int)));
+			connect(m_connection, TQ_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), this, TQ_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
+			connect(m_connection, TQ_SIGNAL(sigClientLost()), this, TQ_SLOT(slotClientLost()));
+			connect(m_connection, TQ_SIGNAL(sigAbortNetworkGame()), this, TQ_SLOT(slotAbortNetworkGame()));
+			connect(m_connection, TQ_SIGNAL(sigReplay()), this, TQ_SLOT(slotReplayRequest()));
+			connect(m_connection, TQ_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQ_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
+			connect(m_connection, TQ_SIGNAL(sigLost(KMessage *)), this, TQ_SLOT(slotLost(KMessage *)));
 		}
 		else
 			m_connection->updateInternal(m_kbserver);
@@ -1119,51 +1119,51 @@ void KBattleshipWindow::slotConnectToBattleshipServer(const TQString &host, int
 	if(m_connection == 0)
 	{
 		m_connection = new KonnectionHandling(this, m_kbclient);
-		connect(m_kbclient, TQT_SIGNAL(sigConnected()), TQT_TQOBJECT(this), TQT_SLOT(slotSendVersion()));
-		connect(m_connection, TQT_SIGNAL(sigAbortNetworkGame()), TQT_TQOBJECT(this), TQT_SLOT(slotAbortNetworkGame()));
-		connect(m_connection, TQT_SIGNAL(sigStatusBar(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotStatusMsg(const TQString &)));
-		connect(m_connection, TQT_SIGNAL(sigEnemyNickname(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeEnemyPlayer(const TQString &)));
-		connect(m_connection, TQT_SIGNAL(sigSendFieldState(int, int)), TQT_TQOBJECT(this), TQT_SLOT(slotSendEnemyFieldState(int, int)));
-		connect(m_connection, TQT_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), TQT_TQOBJECT(this), TQT_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
-		connect(m_connection, TQT_SIGNAL(sigShootable(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetShootable(bool)));
-		connect(m_connection, TQT_SIGNAL(sigPlaceShips(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetPlaceable(bool)));
-		connect(m_connection, TQT_SIGNAL(sigServerLost()), TQT_TQOBJECT(this), TQT_SLOT(slotServerLost()));
-		connect(m_connection, TQT_SIGNAL(sigReplay()), TQT_TQOBJECT(this), TQT_SLOT(slotReplay()));
-		connect(m_connection, TQT_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQT_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
-		connect(m_connection, TQT_SIGNAL(sigClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotReceivedClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)));
-		connect(m_connection, TQT_SIGNAL(sigLost(KMessage *)), TQT_TQOBJECT(this), TQT_SLOT(slotLost(KMessage *)));
+		connect(m_kbclient, TQ_SIGNAL(sigConnected()), this, TQ_SLOT(slotSendVersion()));
+		connect(m_connection, TQ_SIGNAL(sigAbortNetworkGame()), this, TQ_SLOT(slotAbortNetworkGame()));
+		connect(m_connection, TQ_SIGNAL(sigStatusBar(const TQString &)), this, TQ_SLOT(slotStatusMsg(const TQString &)));
+		connect(m_connection, TQ_SIGNAL(sigEnemyNickname(const TQString &)), this, TQ_SLOT(slotChangeEnemyPlayer(const TQString &)));
+		connect(m_connection, TQ_SIGNAL(sigSendFieldState(int, int)), this, TQ_SLOT(slotSendEnemyFieldState(int, int)));
+		connect(m_connection, TQ_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), this, TQ_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
+		connect(m_connection, TQ_SIGNAL(sigShootable(bool)), this, TQ_SLOT(slotSetShootable(bool)));
+		connect(m_connection, TQ_SIGNAL(sigPlaceShips(bool)), this, TQ_SLOT(slotSetPlaceable(bool)));
+		connect(m_connection, TQ_SIGNAL(sigServerLost()), this, TQ_SLOT(slotServerLost()));
+		connect(m_connection, TQ_SIGNAL(sigReplay()), this, TQ_SLOT(slotReplay()));
+		connect(m_connection, TQ_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQ_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
+		connect(m_connection, TQ_SIGNAL(sigClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)), this, TQ_SLOT(slotReceivedClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)));
+		connect(m_connection, TQ_SIGNAL(sigLost(KMessage *)), this, TQ_SLOT(slotLost(KMessage *)));
 	}
 	else
 	{
 		if(m_connection->type() == KonnectionHandling::SERVER)
 		{
-			disconnect(m_connection, TQT_SIGNAL(sigStatusBar(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotStatusMsg(const TQString &)));
-			disconnect(m_connection, TQT_SIGNAL(sigEnemyNickname(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeEnemyPlayer(const TQString &)));
-			disconnect(m_connection, TQT_SIGNAL(sigSendNickname()), TQT_TQOBJECT(this), TQT_SLOT(slotSendGreet()));
-			disconnect(m_connection, TQT_SIGNAL(sigPlaceShips(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetPlaceable(bool)));
-			disconnect(m_connection, TQT_SIGNAL(sigShootable(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetShootable(bool)));
-			disconnect(m_connection, TQT_SIGNAL(sigSendFieldState(int, int)), TQT_TQOBJECT(this), TQT_SLOT(slotSendEnemyFieldState(int, int)));
-			disconnect(m_connection, TQT_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), TQT_TQOBJECT(this), TQT_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
-			disconnect(m_connection, TQT_SIGNAL(sigClientLost()), TQT_TQOBJECT(this), TQT_SLOT(slotClientLost()));
-			disconnect(m_connection, TQT_SIGNAL(sigAbortNetworkGame()), TQT_TQOBJECT(this), TQT_SLOT(slotAbortNetworkGame()));
-			disconnect(m_connection, TQT_SIGNAL(sigReplay()), TQT_TQOBJECT(this), TQT_SLOT(slotReplayRequest()));
-			disconnect(m_connection, TQT_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQT_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
-			disconnect(m_connection, TQT_SIGNAL(sigLost(KMessage *)), TQT_TQOBJECT(this), TQT_SLOT(slotLost(KMessage *)));
+			disconnect(m_connection, TQ_SIGNAL(sigStatusBar(const TQString &)), this, TQ_SLOT(slotStatusMsg(const TQString &)));
+			disconnect(m_connection, TQ_SIGNAL(sigEnemyNickname(const TQString &)), this, TQ_SLOT(slotChangeEnemyPlayer(const TQString &)));
+			disconnect(m_connection, TQ_SIGNAL(sigSendNickname()), this, TQ_SLOT(slotSendGreet()));
+			disconnect(m_connection, TQ_SIGNAL(sigPlaceShips(bool)), this, TQ_SLOT(slotSetPlaceable(bool)));
+			disconnect(m_connection, TQ_SIGNAL(sigShootable(bool)), this, TQ_SLOT(slotSetShootable(bool)));
+			disconnect(m_connection, TQ_SIGNAL(sigSendFieldState(int, int)), this, TQ_SLOT(slotSendEnemyFieldState(int, int)));
+			disconnect(m_connection, TQ_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), this, TQ_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
+			disconnect(m_connection, TQ_SIGNAL(sigClientLost()), this, TQ_SLOT(slotClientLost()));
+			disconnect(m_connection, TQ_SIGNAL(sigAbortNetworkGame()), this, TQ_SLOT(slotAbortNetworkGame()));
+			disconnect(m_connection, TQ_SIGNAL(sigReplay()), this, TQ_SLOT(slotReplayRequest()));
+			disconnect(m_connection, TQ_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQ_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
+			disconnect(m_connection, TQ_SIGNAL(sigLost(KMessage *)), this, TQ_SLOT(slotLost(KMessage *)));
 			m_connection->updateInternal(m_kbclient);
-			connect(m_kbclient, TQT_SIGNAL(sigConnected()), TQT_TQOBJECT(this), TQT_SLOT(slotSendVersion()));
-			connect(m_connection, TQT_SIGNAL(sigAbortNetworkGame()), TQT_TQOBJECT(this), TQT_SLOT(slotAbortNetworkGame()));
-			connect(m_connection, TQT_SIGNAL(sigStatusBar(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotStatusMsg(const TQString &)));
-			connect(m_connection, TQT_SIGNAL(sigEnemyNickname(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeEnemyPlayer(const TQString &)));
-			connect(m_connection, TQT_SIGNAL(sigSendFieldState(int, int)), TQT_TQOBJECT(this), TQT_SLOT(slotSendEnemyFieldState(int, int)));
-			connect(m_connection, TQT_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), TQT_TQOBJECT(this), TQT_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
-			connect(m_connection, TQT_SIGNAL(sigShootable(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetShootable(bool)));
-			connect(m_connection, TQT_SIGNAL(sigPlaceShips(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSetPlaceable(bool)));
-			connect(m_connection, TQT_SIGNAL(sigServerLost()), TQT_TQOBJECT(this), TQT_SLOT(slotServerLost()));
-			connect(m_connection, TQT_SIGNAL(sigReplay()), TQT_TQOBJECT(this), TQT_SLOT(slotReplay()));
-			connect(m_connection, TQT_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQT_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
+			connect(m_kbclient, TQ_SIGNAL(sigConnected()), this, TQ_SLOT(slotSendVersion()));
+			connect(m_connection, TQ_SIGNAL(sigAbortNetworkGame()), this, TQ_SLOT(slotAbortNetworkGame()));
+			connect(m_connection, TQ_SIGNAL(sigStatusBar(const TQString &)), this, TQ_SLOT(slotStatusMsg(const TQString &)));
+			connect(m_connection, TQ_SIGNAL(sigEnemyNickname(const TQString &)), this, TQ_SLOT(slotChangeEnemyPlayer(const TQString &)));
+			connect(m_connection, TQ_SIGNAL(sigSendFieldState(int, int)), this, TQ_SLOT(slotSendEnemyFieldState(int, int)));
+			connect(m_connection, TQ_SIGNAL(sigEnemyFieldData(int, int, int, int, int, int, int, bool)), this, TQ_SLOT(slotReceivedEnemyFieldData(int, int, int, int, int, int, int, bool)));
+			connect(m_connection, TQ_SIGNAL(sigShootable(bool)), this, TQ_SLOT(slotSetShootable(bool)));
+			connect(m_connection, TQ_SIGNAL(sigPlaceShips(bool)), this, TQ_SLOT(slotSetPlaceable(bool)));
+			connect(m_connection, TQ_SIGNAL(sigServerLost()), this, TQ_SLOT(slotServerLost()));
+			connect(m_connection, TQ_SIGNAL(sigReplay()), this, TQ_SLOT(slotReplay()));
+			connect(m_connection, TQ_SIGNAL(sigChatMessage(const TQString &, const TQString &, bool)), m_chat, TQ_SLOT(slotReceivedMessage(const TQString &, const TQString &, bool)));
 			m_kbclient->init();
-			connect(m_connection, TQT_SIGNAL(sigClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotReceivedClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)));
-			connect(m_connection, TQT_SIGNAL(sigLost(KMessage *)), TQT_TQOBJECT(this), TQT_SLOT(slotLost(KMessage *)));
+			connect(m_connection, TQ_SIGNAL(sigClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)), this, TQ_SLOT(slotReceivedClientInformation(const TQString &, const TQString &, const TQString &, const TQString &)));
+			connect(m_connection, TQ_SIGNAL(sigLost(KMessage *)), this, TQ_SLOT(slotLost(KMessage *)));
 		}
 		else
 			m_connection->updateInternal(m_kbclient);
@@ -1234,7 +1234,7 @@ void KBattleshipWindow::slotSinglePlayer()
 			slotStatusMsg(i18n("Ready"));
 			m_stat->clear();
 			m_chat->clear();
-			TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(slotDeleteAI()));
+			TQTimer::singleShot(0, this, TQ_SLOT(slotDeleteAI()));
 			cleanup(false);
 		}
 	}
@@ -1269,8 +1269,8 @@ void KBattleshipWindow::slotStartBattleshipGame(bool clearstat)
 	{
 		m_aiPlayer = new KBAIPlayer();
 		m_aiPlayer->init(m_view->field(), m_enemyshiplist);
-		connect(m_aiPlayer, TQT_SIGNAL(sigReady()), TQT_TQOBJECT(this), TQT_SLOT(slotAIReady()));
-		connect(m_aiPlayer, TQT_SIGNAL(sigShootAt(const TQPoint)), TQT_TQOBJECT(this), TQT_SLOT(slotAIShootsAt(const TQPoint)));
+		connect(m_aiPlayer, TQ_SIGNAL(sigReady()), this, TQ_SLOT(slotAIReady()));
+		connect(m_aiPlayer, TQ_SIGNAL(sigShootAt(const TQPoint)), this, TQ_SLOT(slotAIShootsAt(const TQPoint)));
 	}
 	m_aiPlayer->slotRestart();
 }
@@ -1320,11 +1320,11 @@ void KBattleshipWindow::slotAIShootsAt(const TQPoint pos)
 		switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?"), TQString(), i18n("Restart"), i18n("Do Not Restart")))
 		{
 			case KMessageBox::Yes:
-				TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(slotRestartAI()));
+				TQTimer::singleShot(0, this, TQ_SLOT(slotRestartAI()));
 				break;
 
 			case KMessageBox::No:
-				TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(slotDeleteAI()));
+				TQTimer::singleShot(0, this, TQ_SLOT(slotDeleteAI()));
 				break;
 		}
 	}
