@@ -13,7 +13,7 @@ class Board;
 
 class EvalDlgImpl: public EvalDlg
 {
- Q_OBJECT
+ TQ_OBJECT
   
 
  public:
